# FulfillmentState

The state of the Fulfillment. See [State transitions for an order, order line item, and fulfillment](https://knowledgecenter.zuora.com/Billing/Subscriptions/Orders/Order_Line_Items/AB_Order_Line_Item_States_and_Order_States) for more information. 

## Enum

* `EXECUTING` (value: `'Executing'`)

* `BOOKED` (value: `'Booked'`)

* `SENTTOBILLING` (value: `'SentToBilling'`)

* `COMPLETE` (value: `'Complete'`)

* `CANCELLED` (value: `'Cancelled'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


